function [input_array_int_0] = plot_spectrogram(input, bands, coldepth, sampRate)
% plot_spectrogram() takes the output variable meanPower (1D cell array),
% and plots a spectrogram by doing the following.
%   1. Convert 1D to 2D cell array.
%   2. Replace values of -1 with NaN.
%   3. Fill missing using linear interpolation and nearest values for
%   endpoint.
%   4. Replace negative values with 0 in case interpolation introduces
%   some.
%   5. Plot spectrogram.

% check inputs and set default arguments
if nargin < 3 || isempty(coldepth)
   coldepth = []; % default use auto select coldepth
end
if nargin < 4 || isempty(sampRate)
    sampRate = 5000; %default use 5000 Hz
end

%convert from cell to mattlab array
input_array = cell2mat(input); % 1D to 2D cell array
input_array(input_array == -1) = NaN; % Replace -1 with NaN
% Fill NaN with linear interpolation.
input_array_int = fillmissing(input_array,'linear',1,'EndValues','nearest');

%get xvalues
xvalues = (1:length(input_array_int))/sampRate;

% Compare original and interpolated array to check correct rows have been
% altered
arr_comp = input_array ~= input_array_int;

% Check which values are <0 if needed
arr_check_0 = input_array_int < 0;
% Replace negative values with 0
input_array_int_0 = input_array_int;
input_array_int_0(input_array_int_0 < 0) = 0;

% if bands are unevenly spaced
zplot = zeros(bands(end), length(xvalues));
for i = 1:length(bands)-1
    if bands(i) < 1
        zplot(1:bands(1)-1,:) = zeros(1:bands(1)-1, length(xvalues));
    end
    bandline = input_array_int_0(i,:);
    nreps = (bands(i+1)-bands(i));
    zplot(bands(i):bands(i+1)-1,:) = repmat(bandline, nreps, 1);
end

% Plot spectrogram
figure;
% coldepth = [0, 0.01];
yvalues = [0 bands(end)]+0.5;
imagesc(xvalues, yvalues, zplot);

% set the colour bar limits
ax = gca;
if isempty(coldepth)
    coldepth = [ax.CLim];
end
ax.CLim = coldepth;

% imagesc(xvalues, yvalues, zplot);
ylim([0 bands(end)]);
set(gca,'YDir','normal');
colorbar;
end