library(dplyr)
library(tidyr)

# Function for doing stats -----------------------------------------------------
doANOVA <- function(list_of_dataframes){

  for (test_num in 1:length(list_of_dataframes)){
    dataframe_for_test <- data.frame(list_of_dataframes[test_num], check.names = FALSE)
    dataframe_for_test <- na.omit(dataframe_for_test)
    current_results <- nextANOVA(dataframe_for_test, test_num)
    current_results_tukey <- data.frame(current_results[1], check.names = FALSE)
    current_results_df <- data.frame(current_results[2], check.names = FALSE)
    current_results_f <- data.frame(current_results[3], check.names = FALSE)
    current_results_p <- data.frame(current_results[4], check.names = FALSE)
    

    if (test_num == 1){ 
      all_results_tukey <- current_results_tukey
      all_results_df <- current_results_df
      all_results_f <- current_results_f
      all_results_p <- current_results_p
    }else{
      all_results_tukey <- rbind(all_results_tukey, current_results_tukey)
      all_results_df <- rbind(all_results_df, current_results_df)
      all_results_f <- rbind(all_results_f, current_results_f)
      all_results_p <- rbind(all_results_p, current_results_p)
    }
  }
  
  all_results_tukey <- all_results_tukey[ , colSums(is.na(all_results_tukey)) == 0]
  all_results_df <- all_results_df[ , colSums(is.na(all_results_df)) == 0]
  all_results_f <- all_results_f[ , colSums(is.na(all_results_f)) == 0]
  all_results_p <- all_results_p[ , colSums(is.na(all_results_p)) == 0]
  
  write.csv(all_results_tukey, file.path(results_folder, "Anova_Two-way_TukeyPvals.csv"))
  write.csv(all_results_df, file.path(results_folder, "Anova_Two-way_Df.csv"))
  write.csv(all_results_f, file.path(results_folder, "Anova_Two-way_F.csv"))
  write.csv(all_results_p, file.path(results_folder, "Anova_Two-way_P.csv"))
  
  return(all_results_tukey)
}


nextANOVA <- function(dataframe_for_test, test_num){
  
  # Make matrix based on size of results
  num_levels <- length(levels(factor(dataframe_for_test$Condition)))
  num_results_rows <- sum(1:num_levels-1)
  cols <- colnames(dataframe_for_test)
  current_results <- matrix(nrow=num_results_rows, ncol = (dim(dataframe_for_test)[2]))
  current_results <- data.frame(current_results)
  colnames(current_results) <- cols

  current_results$Muscle[1:length(current_results$Muscle )] <- levels(factor(dataframe_for_test$Muscle))
  
  colnames(current_results)[colnames(current_results)=="Subject"] <- "Test no."
  current_results$`Test no.`[1:length(current_results$`Test no.` )] <- test_num
  
  # copy for degrees of freedom, F values, and p values.
  current_results_df <- current_results[1:5]
  colnames(current_results_df)[5] <- 'Df' 
  current_results_f <- current_results
  current_results_p <- current_results
  
  #Perform ANOVAS and fill results matrix    
  for (band in 5:(dim(dataframe_for_test)[2])){
    band_name <- colnames(dataframe_for_test[band])
    band_data <- data.frame(dataframe_for_test[band])
    
    data_twoway <- dataframe_for_test[c(1,2,band)]
    colnames(data_twoway)[3] <- 'Power'
    data_twoway$Subject <- factor(data_twoway$Subject)
    data_twoway$Condition <- factor(data_twoway$Condition)
    
    anova_results <- aov(Power ~ Subject + Condition, data = data_twoway) #two way

    anova_df <- as.data.frame(summary(anova_results)[[1]])
  
    tukey_results <- TukeyHSD(anova_results, ("Condition"), conf.level=.99,ordered = FALSE) 
    tukey_dataframe <- as.data.frame(tukey_results$Condition)
    
    #Add Bonferonni correction
    tukey_p <- as.matrix(tukey_dataframe[4])
    tukey_p_corrected <- p.adjust(tukey_p, method = "bonferroni")
    
    
    if(ndrs == 3 && test_num == 3){
      pause <- 1 
    }
    
    
    # for tukey results
    new_results <- data.frame(tukey_p_corrected)
    current_results[,(band)] <- new_results[,1]
    current_results$Condition <- rownames(tukey_dataframe[1:num_results_rows,])
    
    # for f, and p vals
    current_results_f[,(band)] <- anova_df$'F value'[2]
    current_results_f$Condition <- rownames(tukey_dataframe[1:num_results_rows,])
    
    current_results_p[,(band)] <- anova_df$'Pr(>F)'[2]
    current_results_p$Condition <- rownames(tukey_dataframe[1:num_results_rows,])
    next
  }
  # for df
  current_results_df$Df <- anova_df$Df[2]
  current_results_df$Condition <- rownames(tukey_dataframe[1:num_results_rows,])
  
  return(list(current_results, current_results_df, current_results_f, current_results_p))
}

# Function for standard error --------------------------------------------------
sem <- function(x) sd(x)/sqrt(length(x))

# Function to perform work -----------------------------------------------------
dowork <- function (inputdir){
  setwd(inputdir)
  
  # lists of names of results files and subjects
  input_file_list <- c("aa.csv","am.csv","bh.csv","cg.csv","jd.csv","jg.csv",
                       "mattp.csv","mk.csv","ps.csv","rd.csv")
  subject_name_list <- c("aa","am","bh","cg","jd","jg","mattp","mk","ps","rd")
  
  # accumulate data from all subjects into single datafame
  all_subject_data <- read.csv(file = input_file_list[1], header = TRUE, sep = ";", check.names = FALSE)
  
  for (file_no in 2:length(input_file_list)){
    inputfile <- input_file_list[file_no]
    subject_data <- read.csv(file = inputfile, header = TRUE, sep = ";", check.names = FALSE)
    # subject_dataframe <- data.frame(subject_data, check.names = FALSE)
    all_subject_data <- rbind(all_subject_data, subject_data)
    next
  }
  
  all_subject_data <- all_subject_data %>%
    select_if(function(x) !any(x == -1)) %>%
    filter(Event %in% c('P1','cycle','iso'),
           grepl('mwave*', Condition)) %>% 
    select(-c(Seg, 'Matlab Input', Latency))
  
  # for n numbers
  trials_per_subject_mwave <- all_subject_data %>% 
    group_by(Condition, Subject, Muscle)%>%
    summarise(N = n()) %>%
    ungroup() %>%
    filter(grepl('mwave*', Condition)) %>% 
    pivot_wider(names_from = Subject, values_from = N) %>%
    group_by(Condition, Muscle) %>% 
    mutate(Total = sum(c_across(aa:rd)),
           across(where(is.numeric), replace_na, 0),
           Total_subjects = sum(c_across(aa:rd) != 0))%>% 
    arrange(Condition)
  
  
  # save as csv
  write.csv(trials_per_subject_mwave, paste0(outputdir, '/N_trials_per_sub_mwave_only.csv'))

  # collect data for different ANOVA tests
  mwave_vals_bic <- all_subject_data %>% 
    filter(grepl('mwave*', Condition),
           Muscle == 'biceps')
  
  mwave_vals_tric <- all_subject_data %>% 
    filter(grepl('mwave*', Condition),
           Muscle == 'triceps')
  
  # organise raw data for ANOVAs and calculate
  raw_data_for_tests <- list(mwave_vals_bic, mwave_vals_tric)
  finalresults <- doANOVA(raw_data_for_tests)
  
}

# WORK STARTS HERE -------------------------------------------------------------
# set working directory to the folder containing the script
root_dir <- dirname(rstudioapi::getActiveDocumentContext()$path)
print(root_dir)
setwd(root_dir)

# look for a folder called 'Final Results'
resultsdir <- file.path(dirname(root_dir), 'Step3_frequency_analysis/Results')

# check or create general outputdir
outputdir <- file.path(root_dir, 'Frequency_stats/Supplemental_Mwave')


if (file.exists(outputdir) == FALSE){
  dir.create(file.path(outputdir))
}

# get a list of subfolders
subdirlist <- list.dirs(path = resultsdir, recursive = FALSE)

numdirs <- length(subdirlist) 
#numdirs <- 1 #### TAKE OUT THIS LINE TO DO ALL DIRECTORIES

# loop through all results folders
for (ndrs in 1: numdirs){
  if((subdirlist[ndrs] != outputdir) & (subdirlist[ndrs] != resultsdir)){
    
    # Check existence or create specific results folder
    results_folder <- file.path(outputdir, basename(subdirlist[ndrs]))
    if (file.exists(results_folder) == FALSE){
      dir.create(file.path(results_folder))
    }
    
    # Run ANOVAs
    dowork(subdirlist[ndrs])
    next
  }
}
