library(rJava)
library(xlsx)
library(xlsxjars)
library(tiff)
library(dplyr)

# Function for standard error
sem <- function(x) sd(x)/sqrt(length(x))

# Function for plotting line graphs
plotlinegraphs <- function(xx, yy){
  
  # Define conditions and muscles for plots 
  plotnames <- list("Cycling: 6 o'clock","Tonic: 6 o'clock","Cycling: 12 o'clock","Tonic: 12 o'clock")
  condtits <- list("Baseline", expression(paste(Delta, " from Baseline with Stim.")))
  condnames <- list("Cycle Flex.","Iso. Flex.","Cycle Ext.","Iso. Ext.")
  muscles <- list("Biceps","Triceps")
  pointtypes <- c( 21, 22, 24)
  pointleg <- c("Control", "TMS", "TMES")
  lineleg <- c("Control", "Onset", "P1", "P2")
  xticks <- seq(0, 150, 30)
  
  # Line colour list (for 6 lines)
  lcolour <- (1) #DEFINE OBJECT
  lcolour[1] <- rgb(0,0,255, maxColorValue = 255)      #blue
  lcolour[2] <- rgb(0,255,0, maxColorValue = 255)      #green
  lcolour[3] <- rgb(0,255,255, maxColorValue = 255)    #cyan
  lcolour[4] <- rgb(255,0,0, maxColorValue = 255)      #red
  lcolour[5] <- rgb(255,255,0, maxColorValue = 255)    #yellow
  lcolour[6] <- rgb(0,0,0, maxColorValue = 255)        #black
  
  condcol <- c(lcolour[2], lcolour[4], lcolour[1], lcolour[3] )
  
  # Fill colour list
  fcolour <- (1) #DEFINE OBJECT
  fcolour[1] <- rgb(0,0,255,50, maxColorValue = 255)      #blue
  fcolour[2] <- rgb(0,255,0,50, maxColorValue = 255)      #green
  fcolour[3] <- rgb(0,255,255,50, maxColorValue = 255)    #cyan
  fcolour[4] <- rgb(255,0,0,50, maxColorValue = 255)      #red
  fcolour[5] <- rgb(255,255,0,50, maxColorValue = 255)    #yellow
  fcolour[6] <- rgb(0,0,0,50, maxColorValue = 255)        #black
  
  # Define parameters for plotting
  op <- par(mfcol=c(2, 4),
            #windows(xpos = 0, ypos = 0, width = 1000, height = 300, units = "px"),
            windows(xpos = 0, ypos = 0, width = 40, height = 22),
            #mai = c(0.1, 0, 0.1, 0.1)+ 0.1, # MARGINS IN INCHES
            oma = c(8,10,5,4)+0.1,              # Margins for outer margins plot: c(bottom, left, top, right)
            mar = c(0,2,4,0)+0.1)            # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  
  allxdata <- xx[[1]]
  for (t in 2: length(xx)){
    allxdata <- rbind(allxdata, xx[[t]])
  }
  maxx <-max(allxdata[4:length(allxdata)])
  
  allydata <- yy[[1]]
  for (t in 2: length(yy)){
    allydata <- rbind(allydata, yy[[t]])
  }
  maxy <- max(allydata[4:length(allydata)])
  
  ymeansd <- c( 0 , (maxx+maxy))
  #  ymeansd <- c( 0 , 1)
  
  # For each plot, get data
  for (j in 1:length(xx)){
    Means  <- data.frame(xx[j], 
                         check.names = FALSE, 
                         row.names = NULL)
    Error  <- data.frame(yy[j], 
                         check.names = FALSE, 
                         row.names = NULL)
    
    Means <- na.omit(Means)
    Error <- na.omit(Error)
    
    
    MeanVals <- Means[4:length(Means)]
    ErrorVals  <- Error[4:length(Error)]
    
    NumLines <- dim(Means)[1]
    NumVals <- dim(MeanVals)[2]
    
    minX <- as.integer(names(MeanVals[1]))
    maxX <- as.integer(names(MeanVals[length(MeanVals)]))
    axlen <- maxX
    
    # Start plotting -----------------------------------------------------------    
    plot <- plot(1,
                 type="b",
                 col = "white",
                 xlim=c(0,axlen),
                 ylim=ymeansd, 
                 frame.plot=FALSE,
                 xaxt='n',
                 yaxt = 'n')
    
    # For Each condition, plot a new line for each
    for (i in 1:NumLines) {
      a <- MeanVals[i,]
      b <- as.numeric(names(MeanVals))
      # Position in centre of bin (not at start)
      for (f1 in 1:NumVals-1){
        b[f1] <- b[f1]+((b[f1+1]-b[f1])/2)
      } 
      
      
      bsd <- ErrorVals[i,]
      #   linetype <- 1:6
      linetype = 1
      pointtype = 21
      
      # Set line colour
      test <- grep("cycle_12", Means[i,1], TRUE)
      ifelse(test>0,c(lcol <- lcolour[1], fcol <- fcolour[1]), test <-0) # does condition match?
      
      test <- grep("cycle_6", Means[i,1], TRUE)
      ifelse(test>0, c(lcol <- lcolour[2], fcol <- fcolour[2]), test <-0) # does condition match?
      
      test <- grep("iso_12", Means[i,1], TRUE)
      ifelse(test>0, c(lcol <- lcolour[3], fcol <- fcolour[3]), test <-0) # does condition match?
      
      test <- grep("iso_6", Means[i,1], TRUE)
      ifelse(test>0, c(lcol <- lcolour[4], fcol <- fcolour[4]), test <-0) # does condition match?
      
      # Set point type
      #      pch=19: solid circle,
      #      pch=20: bullet,
      #      pch=21: circle,
      #      pch=22: square,
      #      pch=23: diamond,
      #      pch=24: triangle point-up,
      #      pch=25: triangle point down.
      
      
      meptest <- grepl("mep", Means[i,1], TRUE) & !grepl("cmep", Means[i,1], TRUE)
      if (meptest == 1){ pointtype <- 22} # does condition match?
      
      cmeptest <- grepl("cmep", Means[i,1], TRUE)
      if (cmeptest == 1){ pointtype <- 24} # does condition match?
      
      if(Means$Event[i] == "iso" | Means$Event[i] == "cycle"){ pointtype = 21} # does condition match?
      if(Means$Event[i] == "iso" | Means$Event[i] == "cycle"){ linetype = 1} # does condition match?
      
      
      # Plot Mean  
      lines(b, a, type = "l", lty = linetype, col = lcol, lwd = 1)
      
      err_pos <- as.numeric(unlist(a + bsd))
      err_neg <- as.numeric(unlist(a - bsd))
      
      # Plot Mean  
      # Positive Error  
      lines(b, err_pos, type = "l", lty = "dashed", col = lcol, lwd = 0.1)
      # Negative Error
      lines(b, err_neg, type = "l", lty = "dashed", col = lcol, lwd = 0.1)
      # Error Fill
      polygon(c(b,rev(b)), c(err_pos, rev(err_neg)), col = fcol, border = NA)  
      
      xer <- 1:length(err_pos)
      #      arrows(b, err_pos, b, err_neg, code=3, length=0.01, angle = 90, col = lcol, lwd = 0.75)      
      #      
      points(b, a, pch = pointtype, cex = 1, col = "black", bg = "white", lwd = 0.75)
      
      
      # # plot significant points
      # sigvectorrow <- returnsigindex(finalresults, Means[i,], j)
      # pvals <- sigvectorrow[,4:length(sigvectorrow)]
      # if(dim(pvals)[1] > 0){
      #   sigvector <- which(pvals < 0.01)
      #   points(b[sigvector], a[sigvector], pch = pointtype, cex = 1, col = "black", bg = lcol, lwd = 0.75)
      # }
    }
    
    par(las=1)
    if(j == 1){axis(2, lwd =2, cex.axis = 1.5)}
    if(j == 2){axis(2, lwd =2, cex.axis = 1.5)
      title(ylab = "Normalised Power (L1)", outer = TRUE, line = 3, adj = 0, cex.lab = 2.5)}
    # if(j == 3){axis(2, lwd =2, cex.axis = 1.5)}
    # if(j == 4){axis(2, lwd =2, cex.axis = 1.5)}
    #if(j == 4){title(ylab = condtits[2],      outer = FALSE, line = 0, adj = 0, cex.lab = 2.5)}
    
    next
  }
  
  bandsize <- b[2]-b[1]
  
  op1 <- par(mfcol=c(1, 4),
             oma = c(8,10,3,4)+0.1,              # Margins for outer margins plot: c(bottom, left, top, right)
             mar = c(0,2,2,0)+0.1)            # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  for (k in 1:4){
    par(mfg=c(1,k))
    
    #par(xaxp  = c(0, 150, 11))
    # Add name for column 
    title(main = plotnames[k], line = -4.5, adj = 0.5, cex.main = 2, font = 2)
    # Add x-axis
    axis(1, lwd = 2, cex.axis = 1.4, at = xticks, labels = xticks)
    
    # Add legends on right top plot    
    if (k == 4) {
      legend("topright", 
             #x = (b[length(b)]/100)*55, y = (ymeansd[2]/100)*90,
             
             # inset = c(-2,0), 
             col = condcol,
             lty = linetype,
             # lwd = 3,
             # seg.len = 0.3,
             legend = condnames[1:length(condnames)],
             bty = "n",
             box.col = "n",
             # cex = 1, 
             # y.intersp = 0.5,
             # x.intersp = 0.25,
             # horiz = FALSE
      )
    }
    
    
    # Place labes for bands
    xpos <- c(10, 25, 45, 80)
    ylabelpos <- (ymeansd[2]+((ymeansd[2]/100)*2.5))
    #ylabelpos <- ymeansd[2]
    bandlabels <- c(expression(alpha), expression(beta), expression(paste("Lo-",gamma)), expression(paste("Hi-",gamma)))
    text(x = xpos, y = ylabelpos, labels = bandlabels, cex = 1.5, lwd = 2 )
    
    abline(h = 20, v = 8, untf = FALSE, lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 12,untf = FALSE, lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 15, untf = FALSE, lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 35, untf = FALSE,lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 56, untf = FALSE,lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 60, untf = FALSE, lwd = 1.5 )
    abline(h = 20, v = 64, untf = FALSE,lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 100, untf = FALSE,lwd = 1.5, lty = "dashed")
  }
  
  
  # Create Legend
  op2 <- par(mfcol=c(1, 1),
             #mai = c(0, 0, 0, 0)+ 0.1, # Margins (IN INCHES) for individual plot: c(bottom, left, top, right)
             oma = c(10,2,4,0)+0.1, # Margins for outer margins plot: c(bottom, left, top, right)
             mar = c(0,0,0,0)+0.1)           # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  op2 <- par(mfcol=c(2, 1),
             #mai = c(0, 0, 0, 0)+ 0.1, # Margins (IN INCHES) for individual plot: c(bottom, left, top, right)
             oma = c(0,0,0,0)+0.1, # Margins for outer margins plot: c(bottom, left, top, right)
             mar = c(0,0,0,0)+0.1)           # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  
  par(mfg=c(1,1))
  title(main = muscles[1], line = -5, adj =0, cex.main = 2.8)
  
  par(mfg=c(2,1))
  title(main = muscles[2], line = -1.5, adj = 0, cex.main = 2.5)
  title(sub = "Frequency (Hz)", outer = TRUE, line = -2.5, adj = 0.5, cex.sub = 2.5 )
  
  # To save figures ------------------------------------------------------------ 
  pdf_output_dir <- paste0(freq_fig_dir, '/Fig.3.4_WSST_1Hz_Mwave.pdf')
  tiff_output_dir <- paste0(freq_fig_dir, '/Fig.3.4_WSST_1Hz_Mwave.tiff')
  
  # save to file
  dev.copy(pdf,file = pdf_output_dir, width = 30, height = 10)
  dev.off()
  dev.copy(tiff,file = tiff_output_dir, width = 30, height = 10, res = 500, units = "in")
  dev.off()
  
  return(1)
  
}

# Function to organise and do work ---------------------------------------------
dowork <- function (inputdir){
  setwd(inputdir)  
  
  #Name results files into a list
  inputfiles <- c("aa.csv","am.csv","bh.csv","cg.csv","jd.csv","jg.csv","mattp.csv","mk.csv","ps.csv","rd.csv")
  subject <- c("aa","am","bh","cg","jd","jg","mattp","mk","ps","rd")
  
  # Accumulate data from all subjects into one datafame
  Data <- read.csv(file = inputfiles[1], header = TRUE, sep = ";", check.names = FALSE)
  drame <- data.frame(Data, check.names = FALSE)
  
  for (fileno in 2:length(inputfiles)){
    inputfile <- inputfiles[fileno]
    Data <- read.csv(file = inputfile, header = TRUE, sep = ";", check.names = FALSE)
    subdat <- data.frame(Data, check.names = FALSE)
    drame <- rbind(drame, subdat)
    next
  }
  
  drame <- drame[,apply(drame,2,function(drame) !all(drame==-1))]
  drame <- drame %>% filter(grepl("*mwave*", Condition)) %>% filter(Event == "P1")
    
  drame <- subset.data.frame(drame,!(grepl("Onset",drame$Event)))
  stimdrame <- subset.data.frame(drame[c(1,3:5,8:length(drame))])
  drame <- subset.data.frame(drame[c(1,3:5,8:length(drame))])
  
  # Do the same for stimulation values
  valsdf <- stimdrame
  
  
  means <- stimdrame %>%
    group_by(Subject, Condition, Muscle, Event) %>%
    summarise(across(.cols = everything(), ~mean(.)))
  
  meanofmeans <- means %>%
    group_by(Condition, Muscle, Event) %>%
    select(-Subject) %>%
    summarise(across(.cols = everything(), ~mean(.)))
  
  sems <- means %>%
    group_by(Condition, Muscle, Event) %>%
    select(-Subject) %>%
    summarise(across(.cols = everything(), ~sem(.)))
  
  
  # subset for means  
  aa <- meanofmeans %>%
    filter(Muscle == "biceps",
           Condition == "mwave_cycle_6")
  
  bb <- meanofmeans %>%
    filter(Muscle == "triceps",
           Condition == "mwave_cycle_6")
  
  cc <- meanofmeans %>%
    filter(Muscle == "biceps",
           Condition == "mwave_iso_6")
  
  dd <- meanofmeans %>%
    filter(Muscle == "triceps",
           Condition == "mwave_iso_6")
  
  ee <- meanofmeans %>%
    filter(Muscle == "biceps",
           Condition == "mwave_cycle_12")
  
  ff <- meanofmeans %>%
    filter(Muscle == "triceps",
           Condition == "mwave_cycle_12")
  
  gg <- meanofmeans %>%
    filter(Muscle == "biceps",
           Condition == "mwave_iso_12")
  
  hh <- meanofmeans %>%
    filter(Muscle == "triceps",
           Condition == "mwave_iso_12")  
  
  
  # subset for sem  
  aaa <- sems %>%
    filter(Muscle == "biceps",
           Condition == "mwave_cycle_6")
  
  bbb <- sems %>%
    filter(Muscle == "triceps",
           Condition == "mwave_cycle_6")
  
  ccc <- sems %>%
    filter(Muscle == "biceps",
           Condition == "mwave_iso_6")
  
  ddd <- sems %>%
    filter(Muscle == "triceps",
           Condition == "mwave_iso_6")
  
  eee <- sems %>%
    filter(Muscle == "biceps",
           Condition == "mwave_cycle_12")
  
  fff <- sems %>%
    filter(Muscle == "triceps",
           Condition == "mwave_cycle_12")
  
  ggg <- sems %>%
    filter(Muscle == "biceps",
           Condition == "mwave_iso_12")
  
  hhh <- sems %>%
    filter(Muscle == "triceps",
           Condition == "mwave_iso_12")  
  
  # Put data from means (xx) 
  xx <- list(aa,bb,cc,dd,ee,ff,gg,hh)
  yy <- list(aaa,bbb,ccc,ddd,eee,fff,ggg,hhh)
  
  
  plotlinegraphs(xx,yy)
  
  
  
  
  
  
  
  
  
  
  
  
  # Subset means FOR ANOVA
  ## Control values, including control data from both MEP and CMEP. for bic and tric
  # 
  # aaaa <- stimdrame %>%
  #   filter(Muscle == "biceps",
  #          Condition == "mwave_cycle_6")
  # 
  # bbbb <- stimdrame %>%
  #   filter(Muscle == "triceps",
  #          Condition == "mwave_cycle_6")
  # 
  # cccc <- stimdrame %>%
  #   filter(Muscle == "biceps",
  #          Condition == "mwave_iso_6")
  # 
  # dddd <- stimdrame %>%
  #   filter(Muscle == "triceps",
  #          Condition == "mwave_iso_6")
  # 
  # eeee <- stimdrame %>%
  #   filter(Muscle == "biceps",
  #          Condition == "mwave_cycle_12")
  # 
  # ffff <- stimdrame %>%
  #   filter(Muscle == "triceps",
  #          Condition == "mwave_cycle_12")
  # 
  # gggg <- stimdrame %>%
  #   filter(Muscle == "biceps",
  #          Condition == "mwave_iso_12")
  # 
  # hhhh <- stimdrame %>%
  #   filter(Muscle == "triceps",
  #          Condition == "mwave_iso_12")  
  # 
  # anovabic = rbind.data.frame(aaaa,cccc)
  # anovatric = rbind.data.frame(bbbb,dddd)
  # 
  # 
  # # Put data from means (xx) 
  # # xx <- list(aaaa,bbbb,cccc,dddd)
  # # finalresults <- doANOVA(xx)
  # 
  # 
  # 
  # # Calculate difference from meanfor line graphs and subsets ------------------
  # #calculate difvals
  # difvals <- stimvals
  # rows <- dim(difvals)[1]
  # 
  # difvals <- na.omit(difvals)
  # stimvals <- difvals
  # stimvals <- stimvals[-which(stimvals$Event == "iso"), ]
  # stimvals <- stimvals[-which(stimvals$Event == "cycle"), ]
  # stimvals <- na.omit(stimvals)
  # 
  # 
  # stimmeans <- aggregate(stimvals[,5:length(stimvals)], 
  #                        by= list(Subject=stimvals$Subject, 
  #                                 Condition=stimvals$Condition, 
  #                                 Muscle=stimvals$Muscle,
  #                                 Event=stimvals$Event), 
  #                        FUN = mean)
  # 
  # stimmeanofmeans <- aggregate.data.frame(stimmeans[,5:length(stimmeans)],
  #                                         by= list(Condition=stimmeans$Condition, 
  #                                                  Muscle=stimmeans$Muscle,
  #                                                  Event=stimmeans$Event), 
  #                                         FUN = mean)
  # 
  # stimmeanofmeanssem <- aggregate.data.frame(stimmeans[,5:length(stimmeans)],
  #                                            by= list(Condition=stimmeans$Condition, 
  #                                                     Muscle=stimmeans$Muscle,
  #                                                     Event=stimmeans$Event),
  #                                            FUN = sem)
  # 
  # 
  # meanofmeansdf <- rbind(ctrlforstimmeanofmeans, stimmeanofmeans)
  # meanofmeanssemdf <- rbind(ctrlforstimmeanofmeanssem, stimmeanofmeanssem)
  # 
  # # Subset means
  # ## Control values, including control data from both MEP and CMEP. for bic and tric
  # stimmeanofmeans <- stimmeanofmeans[which(stimmeanofmeans$Event == "P1"), ]
  # stimmeanofmeanssem <- stimmeanofmeanssem[which(stimmeanofmeanssem$Event == "P1"), ]
  # 
  # 
  # 
  # 
  # ## control, mep and cmep for each condition (iso/cyc + flex/extension) for biceps and triceps
  # aa <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
  #                (grepl("mep_cycle_6",stimmeanofmeans$Condition) |grepl("mep_iso_6",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "biceps"))
  # 
  # bb <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
  #                (grepl("mep_cycle_6",stimmeanofmeans$Condition) |grepl("mep_iso_6",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "triceps"))
  # 
  # cc <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition))&
  #                (grepl("cmep_cycle_6",stimmeanofmeans$Condition) |grepl("cmep_iso_6",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "biceps"))
  # 
  # dd <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition))&
  #                (grepl("cmep_cycle_6",stimmeanofmeans$Condition) |grepl("cmep_iso_6",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "triceps"))
  # 
  # ee <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
  #                (grepl("mep_cycle_12",stimmeanofmeans$Condition) |grepl("mep_iso_12",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "biceps"))
  # 
  # ff <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
  #                (grepl("mep_cycle_12",stimmeanofmeans$Condition) |grepl("mep_iso_12",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "triceps"))
  # 
  # gg <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition))&
  #                (grepl("cmep_cycle_12",stimmeanofmeans$Condition) |grepl("cmep_iso_12",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "biceps"))
  # 
  # hh <- subset(stimmeanofmeans,  
  #              !(grepl("cont*",stimmeanofmeans$Condition))&
  #                (grepl("cmep_cycle_12",stimmeanofmeans$Condition) |grepl("cmep_iso_12",stimmeanofmeans$Condition))&
  #                (stimmeanofmeans$Muscle == "triceps"))
  # 
  # 
  # 
  # ## control, mep and cmep for each condition (iso/cyc + flex/extension) for biceps and triceps
  # aaa <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
  #                 (grepl("mep_cycle_6",stimmeanofmeanssem$Condition) |grepl("mep_iso_6",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "biceps"))
  # 
  # bbb <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
  #                 (grepl("mep_cycle_6",stimmeanofmeanssem$Condition) |grepl("mep_iso_6",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "triceps"))
  # 
  # ccc <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition))&
  #                 (grepl("cmep_cycle_6",stimmeanofmeanssem$Condition) |grepl("cmep_iso_6",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "biceps"))
  # 
  # ddd <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition))&
  #                 (grepl("cmep_cycle_6",stimmeanofmeanssem$Condition) |grepl("cmep_iso_6",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "triceps"))
  # 
  # eee <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
  #                 (grepl("mep_cycle_12",stimmeanofmeanssem$Condition) |grepl("mep_iso_12",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "biceps"))
  # 
  # fff <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
  #                 (grepl("mep_cycle_12",stimmeanofmeanssem$Condition) |grepl("mep_iso_12",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "triceps"))
  # 
  # ggg <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition))&
  #                 (grepl("cmep_cycle_12",stimmeanofmeanssem$Condition) |grepl("cmep_iso_12",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "biceps"))
  # 
  # hhh <- subset(stimmeanofmeanssem,  
  #               !(grepl("cont*",stimmeanofmeanssem$Condition))&
  #                 (grepl("cmep_cycle_12",stimmeanofmeanssem$Condition) |grepl("cmep_iso_12",stimmeanofmeanssem$Condition))&
  #                 (stimmeanofmeanssem$Muscle == "triceps"))
  # 
  # # Put data from means (xx) 
  # xx <- list(aa,bb,cc,dd,ee,ff,gg,hh)
  # yy <- list(aaa,bbb,ccc,ddd,eee,fff,ggg,hhh)
  # 
  # 
  # plotlinegraphs(xx,yy,finalresults)
  
  return()
}


# Set-up working directories and begin script ----------------------------------
# set working directory to the folder containing the script
root_dir <- dirname(rstudioapi::getActiveDocumentContext()$path)
print(root_dir)
setwd(root_dir)

# Specify relative directory to look for results in
resultsdir <- file.path(dirname(root_dir), 'Step3_frequency_analysis/Results')

# check or create general outputdir
fig_dir <- file.path(root_dir, 'Figures')
freq_fig_dir <- file.path(fig_dir, 'Frequency')

if (file.exists(fig_dir) == FALSE){
  dir.create(fig_dir)}

if (file.exists(freq_fig_dir) == FALSE){
  dir.create(freq_fig_dir)}

# get the directories then filter for results for 1 Hz WSST
subdirlist <- list.dirs(path = resultsdir, recursive = FALSE)
subdirlist <- subdirlist[grepl("WSST", subdirlist) & grepl("Bands1Hz", subdirlist)]
numdirs <- length(subdirlist) 

for (ndrs in 1: numdirs){
  setwd(subdirlist[ndrs])  
  dowork(subdirlist[ndrs])
}