library(rJava)
library(xlsx)
library(xlsxjars)
library(tiff)

# Function for doing stats
doANOVA <- function(dfin){
  df <- data.frame(dfin[1], check.names = FALSE)
  df <- na.omit(df)
  testno <- 1
  allresults <- nextANOVA(df,1)
  
  for (i in 2:length(dfin)){
    foranovadf <- data.frame(dfin[i], check.names = FALSE)
    foranovadf <- na.omit(foranovadf)
    newres <- nextANOVA(foranovadf, i)
    allresults <- rbind(allresults, newres)
  }
  
  allresults <- allresults[ , colSums(is.na(allresults)) == 0]
  
  # Uncomment to save ANOVA results in the results dir
  # outfilename <- paste("Anova_Group_Pvals_Two-way.xlsx")
  # write.xlsx(allresults, outfilename)
  
  return(allresults)
}

# Function to process next ANOVA (next band)
nextANOVA <- function(dfin, testno){
  
  # Make matrix for size of results
  anovagroup <- dfin
  nlevels <- length(levels(factor(anovagroup$Condition)))
  nresrows <- sum(1:nlevels-1)    # COUNT NUMBER OF RESULTS
  cols <- colnames(anovagroup)
  currentresults <- matrix(nrow=nresrows, ncol = (dim(anovagroup)[2]))
  currentresults <-data.frame(currentresults)
  colnames(currentresults) <- cols
  
  currentresults$Muscle[1:length(currentresults$Muscle )] <- levels(factor(anovagroup$Muscle))
  
  colnames(currentresults)[colnames(currentresults)=="Subject"] <- "Test no."
  currentresults$`Test no.`[1:length(currentresults$`Test no.` )] <- testno
  
  #Perform ANOVAS and fill results matrix    
  for (band in 5:(dim(anovagroup)[2])){
    bandname <- colnames(anovagroup[band])
    banddata <- data.frame(anovagroup[band])
    anovaresults <- aov(lm(as.matrix(anovagroup[bandname]) ~ Subject + Condition, anovagroup))
    tukeyresults <- TukeyHSD(anovaresults, ("Condition"), conf.level=.99,ordered = FALSE) 
    tukeydf <- as.data.frame(tukeyresults$Condition)
    
    #Add Bonferonni correction
    tukeyP <- as.matrix(tukeydf[4])
    tukeyPcorrected <- p.adjust(tukeyP, method = "bonferroni", n = length(tukeyP))
    # https://stats.stackexchange.com/questions/9425/bonferroni-or-tukey-when-does-the-number-of-comparisons-become-large
    
    newresults <- data.frame(tukeyPcorrected)
    currentresults[,(band)] <- newresults[,1]
    currentresults$Condition <- rownames(tukeydf[1:nresrows,])
    next
  }
  return(currentresults)
}

# Function for standard error
sem <- function(x) sd(x)/sqrt(length(x))

# Take all ANOVA results and row vectors for test, and return the indexes which are significant ANOVA results
returnsigindex <- function(allanovaresults, rowfortest, plotno){
  
  testmuscle  <- levels(factor(rowfortest$Muscle))
  testcond <- levels(factor(rowfortest$Condition))
  
  if (plotno < 3){
    
    if(grepl("cycle", testcond, TRUE) == TRUE){
      testcondcont <- gsub("cycle", "iso", testcond)}
    
    if(grepl("iso", testcond, TRUE) == TRUE){
      testcondcont <- gsub("iso", "cycle", testcond)}
    
    resultsrow <- subset.data.frame(allanovaresults,
                                    (grepl(paste(testcond, "-", testcondcont, sep = ""), allanovaresults$Condition)
                                     | grepl(paste(testcondcont, "-", testcond, sep = ""), allanovaresults$Condition ))
                                    & grepl(testmuscle, allanovaresults$Muscle))
  }
  
  if (plotno > 2){
    
    if (grepl("cycle", testcond, TRUE) == TRUE){
      testcond2 <- sub("cycle","iso",testcond )}
    
    if (grepl("iso", testcond, TRUE) == TRUE){
      testcond2 <- sub("iso","cycle",testcond )}
    
    paste(testcond, testcond2, sep = "-")
    paste(testcond2, testcond, sep = "-")
    
    resultsrow <- subset.data.frame(allanovaresults,
                                    !grepl("cont", allanovaresults$Condition)&
                                      (grepl(paste(testcond, testcond2, sep = "-"), allanovaresults$Condition) |
                                         grepl(paste(testcond2, testcond, sep = "-"), allanovaresults$Condition)) &
                                      grepl(testmuscle, allanovaresults$Muscle)
    )
    
    print(plotno)
    print(levels(factor(resultsrow$Condition)))
    print(levels(factor(resultsrow$Muscle)))
    print(testmuscle)
  }
  
  sigvectorrow <- resultsrow[]
  return(sigvectorrow)
  
}

# Function for plotting line graphs
plotlinegraphs <- function(xx, yy, finalresults){
  
  # Define conditions and muscles for plots 
  plotnames <- list("Control Condition","TMS: 6 o'clock","TMES: 6 o'clock","TMS: 12 o'clock","TMES: 12 o'clock")
  condtits <- list("Baseline", expression(paste(Delta, " from Baseline with Stim.")))
  condnames <- list("Cycle Flex.","Iso. Flex.","Cycle Ext.","Iso. Ext.")
  muscles <- list("Biceps","Triceps")
  pointtypes <- c( 21, 22, 24)
  pointleg <- c("Control", "TMS", "TMES")
  lineleg <- c("Control", "Onset", "P1", "P2")
  xticks <- seq(0, 150, 30)
  
  # Line colour list (for 6 lines)
  lcolour <- (1) #DEFINE OBJECT
  lcolour[1] <- rgb(0,0,255, maxColorValue = 255)      #blue
  lcolour[2] <- rgb(0,255,0, maxColorValue = 255)      #green
  lcolour[3] <- rgb(0,255,255, maxColorValue = 255)    #cyan
  lcolour[4] <- rgb(255,0,0, maxColorValue = 255)      #red
  lcolour[5] <- rgb(255,255,0, maxColorValue = 255)    #yellow
  lcolour[6] <- rgb(0,0,0, maxColorValue = 255)        #black
  
  condcol <- c(lcolour[2], lcolour[4], lcolour[1], lcolour[3] )
  
  # Fill colour list
  fcolour <- (1) #DEFINE OBJECT
  fcolour[1] <- rgb(0,0,255,50, maxColorValue = 255)      #blue
  fcolour[2] <- rgb(0,255,0,50, maxColorValue = 255)      #green
  fcolour[3] <- rgb(0,255,255,50, maxColorValue = 255)    #cyan
  fcolour[4] <- rgb(255,0,0,50, maxColorValue = 255)      #red
  fcolour[5] <- rgb(255,255,0,50, maxColorValue = 255)    #yellow
  fcolour[6] <- rgb(0,0,0,50, maxColorValue = 255)        #black
  
  # Define parameters for plotting
  op <- par(mfcol=c(2, 5),
            #windows(xpos = 0, ypos = 0, width = 1000, height = 300, units = "px"),
            windows(xpos = 0, ypos = 0, width = 40, height = 22),
            #mai = c(0.1, 0, 0.1, 0.1)+ 0.1, # MARGINS IN INCHES
            oma = c(8,10,5,4)+0.1,              # Margins for outer margins plot: c(bottom, left, top, right)
            mar = c(0,2,4,0)+0.1)            # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  
  allxdata <- xx[[1]]
  for (t in 2: length(xx)){
    allxdata <- rbind(allxdata, xx[[t]])
  }
  maxx <-max(allxdata[4:length(allxdata)])
  
  allydata <- yy[[1]]
  for (t in 2: length(yy)){
    allydata <- rbind(allydata, yy[[t]])
  }
  maxy <- max(allydata[4:length(allydata)])
  
  ymeansd <- c( 0 , (maxx+maxy))
  #  ymeansd <- c( 0 , 1)
  
  # For each plot, get data
  for (j in 1:length(xx)){
    Means  <- data.frame(xx[j], 
                         check.names = FALSE, 
                         row.names = NULL)
    Error  <- data.frame(yy[j], 
                         check.names = FALSE, 
                         row.names = NULL)
    
    Means <- na.omit(Means)
    Error <- na.omit(Error)
    
    
    MeanVals <- Means[4:length(Means)]
    ErrorVals  <- Error[4:length(Error)]
    
    NumLines <- dim(Means)[1]
    NumVals <- dim(MeanVals)[2]
    
    minX <- as.integer(names(MeanVals[1]))
    maxX <- as.integer(names(MeanVals[length(MeanVals)]))
    axlen <- maxX
    
    # Start plotting -----------------------------------------------------------    
    plot <- plot(1,
                 type="b",
                 col = "white",
                 xlim=c(0,axlen),
                 ylim=ymeansd, 
                 frame.plot=FALSE,
                 xaxt='n',
                 yaxt = 'n')
    
    # For Each condition, plot a new line for each
    for (i in 1:NumLines) {
      a <- MeanVals[i,]
      b <- as.numeric(names(MeanVals))
      # Position in centre of bin (not at start)
      for (f1 in 1:NumVals-1){
        b[f1] <- b[f1]+((b[f1+1]-b[f1])/2)
      } 
      
      
      bsd <- ErrorVals[i,]
      #   linetype <- 1:6
      linetype = 1
      pointtype = 21
      
      # Set line colour
      test <- grep("cycle_12", Means[i,1], TRUE)
      ifelse(test>0,c(lcol <- lcolour[1], fcol <- fcolour[1]), test <-0) # does condition match?
      
      test <- grep("cycle_6", Means[i,1], TRUE)
      ifelse(test>0, c(lcol <- lcolour[2], fcol <- fcolour[2]), test <-0) # does condition match?
      
      test <- grep("iso_12", Means[i,1], TRUE)
      ifelse(test>0, c(lcol <- lcolour[3], fcol <- fcolour[3]), test <-0) # does condition match?
      
      test <- grep("iso_6", Means[i,1], TRUE)
      ifelse(test>0, c(lcol <- lcolour[4], fcol <- fcolour[4]), test <-0) # does condition match?
      
      # Set point type
      #      pch=19: solid circle,
      #      pch=20: bullet,
      #      pch=21: circle,
      #      pch=22: square,
      #      pch=23: diamond,
      #      pch=24: triangle point-up,
      #      pch=25: triangle point down.
      
      
      meptest <- grepl("mep", Means[i,1], TRUE) & !grepl("cmep", Means[i,1], TRUE)
      if (meptest == 1){ pointtype <- 22} # does condition match?
      
      cmeptest <- grepl("cmep", Means[i,1], TRUE)
      if (cmeptest == 1){ pointtype <- 24} # does condition match?
      
      if(Means$Event[i] == "iso" | Means$Event[i] == "cycle"){ pointtype = 21} # does condition match?
      if(Means$Event[i] == "iso" | Means$Event[i] == "cycle"){ linetype = 1} # does condition match?
      
      
      # Plot Mean  
      lines(b, a, type = "l", lty = linetype, col = lcol, lwd = 1)
      
      err_pos <- as.numeric(unlist(a + bsd))
      err_neg <- as.numeric(unlist(a - bsd))
      
      # Plot Mean  
      # Positive Error  
      lines(b, err_pos, type = "l", lty = "dashed", col = lcol, lwd = 0.1)
      # Negative Error
      lines(b, err_neg, type = "l", lty = "dashed", col = lcol, lwd = 0.1)
      # Error Fill
      polygon(c(b,rev(b)), c(err_pos, rev(err_neg)), col = fcol, border = NA)  
      
      xer <- 1:length(err_pos)
      #      arrows(b, err_pos, b, err_neg, code=3, length=0.01, angle = 90, col = lcol, lwd = 0.75)      
      #      
      points(b, a, pch = pointtype, cex = 1, col = "black", bg = "white", lwd = 0.75)
      
      
      # plot significant points
      sigvectorrow <- returnsigindex(finalresults, Means[i,], j)
      pvals <- sigvectorrow[,4:length(sigvectorrow)]
      if(dim(pvals)[1] > 0){
        sigvector <- which(pvals < 0.01)
        points(b[sigvector], a[sigvector], pch = pointtype, cex = 1, col = "black", bg = lcol, lwd = 0.75)
      }
    }
    
    par(las=1)
    if(j == 1){axis(2, lwd =2, cex.axis = 1.5)}
    if(j == 2){axis(2, lwd =2, cex.axis = 1.5)
      title(ylab = "Normalised Power (L1)", outer = TRUE, line = 3, adj = 0, cex.lab = 2.5)}
    if(j == 3){axis(2, lwd =2, cex.axis = 1.5)}
    if(j == 4){axis(2, lwd =2, cex.axis = 1.5)}
    #if(j == 4){title(ylab = condtits[2],      outer = FALSE, line = 0, adj = 0, cex.lab = 2.5)}
    
    next
  }
  
  bandsize <- b[2]-b[1]
  
  op1 <- par(mfcol=c(1, 5),
             oma = c(8,10,3,4)+0.1,              # Margins for outer margins plot: c(bottom, left, top, right)
             mar = c(0,2,2,0)+0.1)            # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  for (k in 1:5){
    par(mfg=c(1,k))
    
    #par(xaxp  = c(0, 150, 11))
    # Add name for column 
    title(main = plotnames[k], line = -4.5, adj = 0.5, cex.main = 2, font = 2)
    # Add x-axis
    axis(1, lwd = 2, cex.axis = 1.4, at = xticks, labels = xticks)
    
    # Add legends on right top plot    
    if (k == 5) {
      legend("topright", 
             #x = (b[length(b)]/100)*55, y = (ymeansd[2]/100)*90,
             
             # inset = c(-2,0), 
             col = condcol,
             lty = linetype,
             # lwd = 3,
             # seg.len = 0.3,
             legend = condnames[1:length(condnames)],
             bty = "n",
             box.col = "n",
             # cex = 1, 
             # y.intersp = 0.5,
             # x.intersp = 0.25,
             # horiz = FALSE
      )
    }
    
    
    # Place labes for bands
    xpos <- c(10, 25, 45, 80)
    ylabelpos <- (ymeansd[2]+((ymeansd[2]/100)*2.5))
    #ylabelpos <- ymeansd[2]
    bandlabels <- c(expression(alpha), expression(beta), expression(paste("Lo-",gamma)), expression(paste("Hi-",gamma)))
    text(x = xpos, y = ylabelpos, labels = bandlabels, cex = 1.5, lwd = 2 )
    
    abline(h = 20, v = 8, untf = FALSE, lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 12,untf = FALSE, lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 15, untf = FALSE, lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 35, untf = FALSE,lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 56, untf = FALSE,lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 60, untf = FALSE, lwd = 1.5 )
    abline(h = 20, v = 64, untf = FALSE,lwd = 1.5, lty = "dashed")
    abline(h = 20, v = 100, untf = FALSE,lwd = 1.5, lty = "dashed")
  }
  
  
  # Create Legend
  op2 <- par(mfcol=c(1, 1),
             #mai = c(0, 0, 0, 0)+ 0.1, # Margins (IN INCHES) for individual plot: c(bottom, left, top, right)
             oma = c(10,2,4,0)+0.1, # Margins for outer margins plot: c(bottom, left, top, right)
             mar = c(0,0,0,0)+0.1)           # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  op2 <- par(mfcol=c(2, 1),
             #mai = c(0, 0, 0, 0)+ 0.1, # Margins (IN INCHES) for individual plot: c(bottom, left, top, right)
             oma = c(0,0,0,0)+0.1, # Margins for outer margins plot: c(bottom, left, top, right)
             mar = c(0,0,0,0)+0.1)           # Margins (IN LINES OF TEXT )for individual plot: c(bottom, left, top, right)
  
  
  par(mfg=c(1,1))
  title(main = muscles[1], line = -5, adj =0, cex.main = 2.8)
  
  par(mfg=c(2,1))
  title(main = muscles[2], line = -1.5, adj = 0, cex.main = 2.5)
  title(sub = "Frequency (Hz)", outer = TRUE, line = -2.5, adj = 0.5, cex.sub = 2.5 )
  
  # To save figures ------------------------------------------------------------ 
  pdf_output_dir <- paste0(freq_fig_dir, '/Fig.3.5_WSST_1Hz.pdf')
  tiff_output_dir <- paste0(freq_fig_dir, '/Fig.3.5_WSST_1Hz.tiff')
  
  # save to file
  dev.copy(pdf,file = pdf_output_dir, width = 30, height = 10)
  dev.off()
  dev.copy(tiff,file = tiff_output_dir, width = 30, height = 10, res = 500, units = "in")
  dev.off()
  
  return(1)
  
}

# Function to organise and do work ---------------------------------------------
dowork <- function (inputdir){
  setwd(inputdir)  
  
  #Name results files into a list
  inputfiles <- c("aa.csv","am.csv","bh.csv","cg.csv","jd.csv","jg.csv","mattp.csv","mk.csv","ps.csv","rd.csv")
  subject <- c("aa","am","bh","cg","jd","jg","mattp","mk","ps","rd")
  
  # Accumulate data from all subjects into one datafame
  Data <- read.csv(file = inputfiles[1], header = TRUE, sep = ";", check.names = FALSE)
  drame <- data.frame(Data, check.names = FALSE)
  
  for (fileno in 2:length(inputfiles)){
    inputfile <- inputfiles[fileno]
    Data <- read.csv(file = inputfile, header = TRUE, sep = ";", check.names = FALSE)
    subdat <- data.frame(Data, check.names = FALSE)
    drame <- rbind(drame, subdat)
    next
  }
  
  drame <- drame[,apply(drame,2,function(drame) !all(drame==-1))]
  # drame <- drame[1:(length(drame)-3)]
  
  drame <- subset.data.frame(drame,!(grepl("Onset",drame$Event)))
  stimdrame <- subset.data.frame(drame[c(1,3:5,8:length(drame))])
  drame <- subset.data.frame(drame[c(1,3:5,8:length(drame))])
  
  # Coerce all control values for mep and cmep into one level called cont
  levs <- levels(drame$Condition)
  levs <- gsub('cont_cmep', 'cont', levs)
  levs <- gsub('cont_mep', 'cont', levs)
  levels(drame$Condition) <- levs
  
  # Subset for individual values for control then obtain means
  ctrlvals <- subset.data.frame(drame, 
                                ((grepl("cont*",drame$Condition))&
                                   (drame$Event == "iso" |
                                      drame$Event == "cycle"))) #a few
  
  ctrlmeans <- aggregate.data.frame(ctrlvals[,5:length(ctrlvals)], 
                                    by= list(Subject=ctrlvals$Subject, 
                                             Condition=ctrlvals$Condition, 
                                             Muscle=ctrlvals$Muscle,
                                             Event=ctrlvals$Event), 
                                    FUN = mean)
  
  ctrlmeanofmeans <- aggregate.data.frame(ctrlmeans[,5:length(ctrlmeans)], 
                                          by= list(Condition=ctrlmeans$Condition, 
                                                   Muscle=ctrlmeans$Muscle,
                                                   Event=ctrlmeans$Event), 
                                          FUN = mean)
  
  ctrlmeanofmeanssem  <- aggregate.data.frame(ctrlmeans[,5:length(ctrlmeans)],
                                              by= list(Condition=ctrlmeans$Condition, 
                                                       Muscle=ctrlmeans$Muscle,
                                                       Event=ctrlmeans$Event), 
                                              FUN = sem)
  
  
  # Subset for individual values for control then obtain means
  ctrlforstimvals <- subset.data.frame(stimdrame, 
                                       (grepl("cont_mep*",stimdrame$Condition))&
                                         (stimdrame$Event == "iso" |
                                            stimdrame$Event == "cycle"))
  
  ctrlforstimmeans <- aggregate.data.frame(ctrlforstimvals[,5:length(ctrlforstimvals)], 
                                           by= list(Subject=ctrlforstimvals$Subject, 
                                                    Condition=ctrlforstimvals$Condition, 
                                                    Muscle=ctrlforstimvals$Muscle,
                                                    Event=ctrlforstimvals$Event), 
                                           FUN = mean)
  
  ctrlforstimmeanofmeans <- aggregate.data.frame(ctrlforstimmeans[,5:length(ctrlforstimmeans)], 
                                                 by= list(Condition=ctrlforstimmeans$Condition, 
                                                          Muscle=ctrlforstimmeans$Muscle,
                                                          Event=ctrlforstimmeans$Event), 
                                                 FUN = mean)
  
  ctrlforstimmeanofmeanssem  <- aggregate.data.frame(ctrlforstimmeans[,5:length(ctrlforstimmeans)],
                                                     by= list(Condition=ctrlforstimmeans$Condition, 
                                                              Muscle=ctrlforstimmeans$Muscle,
                                                              Event=ctrlforstimmeans$Event), 
                                                     FUN = sem)
  
  
  # Do the same for stimulation values
  stimvals <- subset.data.frame(stimdrame, 
                                ((grepl("mep*",stimdrame$Condition))&
                                   ((grepl("*6*",stimdrame$Condition)) |(grepl("*12*",stimdrame$Condition))))) #a few
  
  
  valsdf <- rbind(ctrlforstimvals, stimvals)
  
  
  # Subset means FOR ANOVA
  ## Control values, including control data from both MEP and CMEP. for bic and tric
  
  aaaa <- subset(ctrlvals, 
                 (grepl("cont*",ctrlvals$Condition))& 
                   (ctrlvals$Muscle == "biceps"))
  
  bbbb <- subset(ctrlvals, 
                 (grepl("cont*",ctrlvals$Condition))& 
                   (ctrlvals$Muscle == "triceps"))
  
  ## control, mep and cmep for each condition (iso/cyc + flex/extension) for biceps and triceps
  
  cccc <- subset(valsdf,  
                 !(grepl("cont*",valsdf$Condition))&
                   (valsdf$Muscle == "biceps")&
                   (valsdf$Event == "P1"))
  
  dddd <- subset(valsdf,  
                 !(grepl("cont*",valsdf$Condition))&
                   (valsdf$Muscle == "triceps")&
                   (valsdf$Event == "P1"))
  
  
  anovabic = rbind.data.frame(aaaa,cccc)
  anovatric = rbind.data.frame(bbbb,dddd)
  
  
  # Put data from means (xx) 
  xx <- list(aaaa,bbbb,cccc,dddd)
  finalresults <- doANOVA(xx)
  
  
  
  # Calculate difference from meanfor line graphs and subsets ------------------
  #calculate difvals
  difvals <- stimvals
  rows <- dim(difvals)[1]
  
  difvals <- na.omit(difvals)
  stimvals <- difvals
  stimvals <- stimvals[-which(stimvals$Event == "iso"), ]
  stimvals <- stimvals[-which(stimvals$Event == "cycle"), ]
  stimvals <- na.omit(stimvals)
  
  
  stimmeans <- aggregate(stimvals[,5:length(stimvals)], 
                         by= list(Subject=stimvals$Subject, 
                                  Condition=stimvals$Condition, 
                                  Muscle=stimvals$Muscle,
                                  Event=stimvals$Event), 
                         FUN = mean)
  
  stimmeanofmeans <- aggregate.data.frame(stimmeans[,5:length(stimmeans)],
                                          by= list(Condition=stimmeans$Condition, 
                                                   Muscle=stimmeans$Muscle,
                                                   Event=stimmeans$Event), 
                                          FUN = mean)
  
  stimmeanofmeanssem <- aggregate.data.frame(stimmeans[,5:length(stimmeans)],
                                             by= list(Condition=stimmeans$Condition, 
                                                      Muscle=stimmeans$Muscle,
                                                      Event=stimmeans$Event),
                                             FUN = sem)
  
  
  meanofmeansdf <- rbind(ctrlforstimmeanofmeans, stimmeanofmeans)
  meanofmeanssemdf <- rbind(ctrlforstimmeanofmeanssem, stimmeanofmeanssem)
  
  # Subset means
  ## Control values, including control data from both MEP and CMEP. for bic and tric
  stimmeanofmeans <- stimmeanofmeans[which(stimmeanofmeans$Event == "P1"), ]
  stimmeanofmeanssem <- stimmeanofmeanssem[which(stimmeanofmeanssem$Event == "P1"), ]
  
  
  
  aa <- subset(ctrlmeanofmeans, 
               (grepl("cont*",ctrlmeanofmeans$Condition))&
                 (ctrlmeanofmeans$Muscle == "biceps"))
  
  bb <- subset(ctrlmeanofmeans, 
               (grepl("cont*",ctrlmeanofmeans$Condition))& 
                 (ctrlmeanofmeans$Muscle == "triceps"))
  
  ## control, mep and cmep for each condition (iso/cyc + flex/extension) for biceps and triceps
  cc <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
                 (grepl("mep_cycle_6",stimmeanofmeans$Condition) |grepl("mep_iso_6",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "biceps"))
  
  dd <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
                 (grepl("mep_cycle_6",stimmeanofmeans$Condition) |grepl("mep_iso_6",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "triceps"))
  
  ee <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition))&
                 (grepl("cmep_cycle_6",stimmeanofmeans$Condition) |grepl("cmep_iso_6",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "biceps"))
  
  ff <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition))&
                 (grepl("cmep_cycle_6",stimmeanofmeans$Condition) |grepl("cmep_iso_6",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "triceps"))
  
  gg <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
                 (grepl("mep_cycle_12",stimmeanofmeans$Condition) |grepl("mep_iso_12",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "biceps"))
  
  hh <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition)|grepl("*cmep*",stimmeanofmeans$Condition))&
                 (grepl("mep_cycle_12",stimmeanofmeans$Condition) |grepl("mep_iso_12",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "triceps"))
  
  ii <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition))&
                 (grepl("cmep_cycle_12",stimmeanofmeans$Condition) |grepl("cmep_iso_12",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "biceps"))
  
  jj <- subset(stimmeanofmeans,  
               !(grepl("cont*",stimmeanofmeans$Condition))&
                 (grepl("cmep_cycle_12",stimmeanofmeans$Condition) |grepl("cmep_iso_12",stimmeanofmeans$Condition))&
                 (stimmeanofmeans$Muscle == "triceps"))
  
  # Put SEM into variables
  aaa <- subset(ctrlmeanofmeanssem, 
                (grepl("cont*",ctrlmeanofmeanssem$Condition))& 
                  (ctrlmeanofmeanssem$Muscle == "biceps"))
  
  bbb <- subset(ctrlmeanofmeanssem, 
                (grepl("cont*",ctrlmeanofmeanssem$Condition))& 
                  (ctrlmeanofmeanssem$Muscle == "triceps"))
  
  ## control, mep and cmep for each condition (iso/cyc + flex/extension) for biceps and triceps
  ccc <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
                  (grepl("mep_cycle_6",stimmeanofmeanssem$Condition) |grepl("mep_iso_6",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "biceps"))
  
  ddd <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
                  (grepl("mep_cycle_6",stimmeanofmeanssem$Condition) |grepl("mep_iso_6",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "triceps"))
  
  eee <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition))&
                  (grepl("cmep_cycle_6",stimmeanofmeanssem$Condition) |grepl("cmep_iso_6",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "biceps"))
  
  fff <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition))&
                  (grepl("cmep_cycle_6",stimmeanofmeanssem$Condition) |grepl("cmep_iso_6",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "triceps"))
  
  ggg <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
                  (grepl("mep_cycle_12",stimmeanofmeanssem$Condition) |grepl("mep_iso_12",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "biceps"))
  
  hhh <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition)|grepl("*cmep*",stimmeanofmeanssem$Condition))&
                  (grepl("mep_cycle_12",stimmeanofmeanssem$Condition) |grepl("mep_iso_12",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "triceps"))
  
  iii <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition))&
                  (grepl("cmep_cycle_12",stimmeanofmeanssem$Condition) |grepl("cmep_iso_12",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "biceps"))
  
  jjj <- subset(stimmeanofmeanssem,  
                !(grepl("cont*",stimmeanofmeanssem$Condition))&
                  (grepl("cmep_cycle_12",stimmeanofmeanssem$Condition) |grepl("cmep_iso_12",stimmeanofmeanssem$Condition))&
                  (stimmeanofmeanssem$Muscle == "triceps"))
  
  # Put data from means (xx) 
  xx <- list(aa,bb,cc,dd,ee,ff,gg,hh,ii,jj)
  yy <- list(aaa,bbb,ccc,ddd,eee,fff,ggg,hhh,iii,jjj)
  
  
  plotlinegraphs(xx,yy,finalresults)
  
  return(finalresults)
}


# Set-up working directories and begin script ----------------------------------
# set working directory to the folder containing the script
root_dir <- dirname(rstudioapi::getActiveDocumentContext()$path)
print(root_dir)
setwd(root_dir)

# Specify relative directory to look for results in
resultsdir <- file.path(dirname(root_dir), 'Step3_frequency_analysis/Results')

# check or create general outputdir
fig_dir <- file.path(root_dir, 'Figures')
freq_fig_dir <- file.path(fig_dir, 'Frequency')

if (file.exists(fig_dir) == FALSE){
  dir.create(fig_dir)}

if (file.exists(freq_fig_dir) == FALSE){
  dir.create(freq_fig_dir)}

# get the directories then filter for results for 1 Hz WSST
subdirlist <- list.dirs(path = resultsdir, recursive = FALSE)
subdirlist <- subdirlist[grepl("WSST", subdirlist) & grepl("Bands1Hz", subdirlist)]
numdirs <- length(subdirlist) 

for (ndrs in 1: numdirs){
  setwd(subdirlist[ndrs])  
  dowork(subdirlist[ndrs])
}